==> elasticloadbalancingv2-1.4.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/elasticloadbalancingv2/ApplicationListener.java <==
package software.amazon.awscdk.services.elasticloadbalancingv2;

/**
 * Define an ApplicationListener.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.3 (build 1b1062d)", date = "2019-08-14T08:23:50.760Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.elasticloadbalancingv2.$Module.class, fqn = "@aws-cdk/aws-elasticloadbalancingv2.ApplicationListener")
public class ApplicationListener extends software.amazon.awscdk.services.elasticloadbalancingv2.BaseListener implements software.amazon.awscdk.services.elasticloadbalancingv2.IApplicationListener {
    protected ApplicationListener(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public ApplicationListener(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListenerProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Import an existing listener.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.services.elasticloadbalancingv2.IApplicationListener fromApplicationListenerAttributes(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListenerAttributes attrs) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListener.class, "fromApplicationListenerAttributes", software.amazon.awscdk.services.elasticloadbalancingv2.IApplicationListener.class, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(attrs, "attrs is required") });
    }

    /**
     * Add one or more certificates to this listener.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public void addCertificateArns(final java.lang.String _id, final java.util.List<java.lang.String> arns) {
        this.jsiiCall("addCertificateArns", Void.class, new Object[] { java.util.Objects.requireNonNull(_id, "_id is required"), java.util.Objects.requireNonNull(arns, "arns is required") });
    }

    /**
     * Add a fixed response.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void addFixedResponse(final java.lang.String id, final software.amazon.awscdk.services.elasticloadbalancingv2.AddFixedResponseProps props) {
        this.jsiiCall("addFixedResponse", Void.class, new Object[] { java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Load balance incoming requests to the given target groups.
     * 
     * It's possible to add conditions to the TargetGroups added in this way.
     * At least one TargetGroup must be added without conditions.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public void addTargetGroups(final java.lang.String id, final software.amazon.awscdk.services.elasticloadbalancingv2.AddApplicationTargetGroupsProps props) {
        this.jsiiCall("addTargetGroups", Void.class, new Object[] { java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Load balance incoming requests to the given load balancing targets.
     * 
     * This method implicitly creates an ApplicationTargetGroup for the targets
     * involved.
     * 
     * It's possible to add conditions to the targets added in this way. At least
     * one set of targets must be added without conditions.
     * 
     * @return The newly created target group
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationTargetGroup addTargets(final java.lang.String id, final software.amazon.awscdk.services.elasticloadbalancingv2.AddApplicationTargetsProps props) {
        return this.jsiiCall("addTargets", software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationTargetGroup.class, new Object[] { java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Register that a connectable that has been added to this load balancer.
     * 
     * Don't call this directly. It is called by ApplicationTargetGroup.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public void registerConnectable(final software.amazon.awscdk.services.ec2.IConnectable connectable, final software.amazon.awscdk.services.ec2.Port portRange) {
        this.jsiiCall("registerConnectable", Void.class, new Object[] { java.util.Objects.requireNonNull(connectable, "connectable is required"), java.util.Objects.requireNonNull(portRange, "portRange is required") });
    }

    /**
     * Validate this listener.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    protected java.util.List<java.lang.String> validate() {
        return this.jsiiCall("validate", java.util.List.class);
    }

    /**
     * Manage connections to this ApplicationListener.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public software.amazon.awscdk.services.ec2.Connections getConnections() {
        return this.jsiiGet("connections", software.amazon.awscdk.services.ec2.Connections.class);
    }

    /**
     * Load balancer this listener is associated with.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public software.amazon.awscdk.services.elasticloadbalancingv2.IApplicationLoadBalancer getLoadBalancer() {
        return this.jsiiGet("loadBalancer", software.amazon.awscdk.services.elasticloadbalancingv2.IApplicationLoadBalancer.class);
    }
}

==> elasticloadbalancingv2-1.5.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/elasticloadbalancingv2/ApplicationListener.java <==
package software.amazon.awscdk.services.elasticloadbalancingv2;

/**
 * Define an ApplicationListener.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.15.1 (build ceff2ca)", date = "2019-08-21T10:55:00.770Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.elasticloadbalancingv2.$Module.class, fqn = "@aws-cdk/aws-elasticloadbalancingv2.ApplicationListener")
public class ApplicationListener extends software.amazon.awscdk.services.elasticloadbalancingv2.BaseListener implements software.amazon.awscdk.services.elasticloadbalancingv2.IApplicationListener {

    protected ApplicationListener(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ApplicationListener(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }
    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public ApplicationListener(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListenerProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        this.setObjRef(software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") }));
    }

    /**
     * Import an existing listener.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.services.elasticloadbalancingv2.IApplicationListener fromApplicationListenerAttributes(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListenerAttributes attrs) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationListener.class, "fromApplicationListenerAttributes", software.amazon.awscdk.services.elasticloadbalancingv2.IApplicationListener.class, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(attrs, "attrs is required") });
    }

    /**
     * Add one or more certificates to this listener.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public void addCertificateArns(final java.lang.String _id, final java.util.List<java.lang.String> arns) {
        this.jsiiCall("addCertificateArns", Void.class, new Object[] { java.util.Objects.requireNonNull(_id, "_id is required"), java.util.Objects.requireNonNull(arns, "arns is required") });
    }

    /**
     * Add a fixed response.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void addFixedResponse(final java.lang.String id, final software.amazon.awscdk.services.elasticloadbalancingv2.AddFixedResponseProps props) {
        this.jsiiCall("addFixedResponse", Void.class, new Object[] { java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Load balance incoming requests to the given target groups.
     * 
     * It's possible to add conditions to the TargetGroups added in this way.
     * At least one TargetGroup must be added without conditions.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public void addTargetGroups(final java.lang.String id, final software.amazon.awscdk.services.elasticloadbalancingv2.AddApplicationTargetGroupsProps props) {
        this.jsiiCall("addTargetGroups", Void.class, new Object[] { java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Load balance incoming requests to the given load balancing targets.
     * 
     * This method implicitly creates an ApplicationTargetGroup for the targets
     * involved.
     * 
     * It's possible to add conditions to the targets added in this way. At least
     * one set of targets must be added without conditions.
     * 
     * @return The newly created target group
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationTargetGroup addTargets(final java.lang.String id, final software.amazon.awscdk.services.elasticloadbalancingv2.AddApplicationTargetsProps props) {
        return this.jsiiCall("addTargets", software.amazon.awscdk.services.elasticloadbalancingv2.ApplicationTargetGroup.class, new Object[] { java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Register that a connectable that has been added to this load balancer.
     * 
     * Don't call this directly. It is called by ApplicationTargetGroup.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public void registerConnectable(final software.amazon.awscdk.services.ec2.IConnectable connectable, final software.amazon.awscdk.services.ec2.Port portRange) {
        this.jsiiCall("registerConnectable", Void.class, new Object[] { java.util.Objects.requireNonNull(connectable, "connectable is required"), java.util.Objects.requireNonNull(portRange, "portRange is required") });
    }

    /**
     * Validate this listener.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    protected java.util.List<java.lang.String> validate() {
        return this.jsiiCall("validate", java.util.List.class);
    }

    /**
     * Manage connections to this ApplicationListener.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public software.amazon.awscdk.services.ec2.Connections getConnections() {
        return this.jsiiGet("connections", software.amazon.awscdk.services.ec2.Connections.class);
    }

    /**
     * Load balancer this listener is associated with.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public software.amazon.awscdk.services.elasticloadbalancingv2.IApplicationLoadBalancer getLoadBalancer() {
        return this.jsiiGet("loadBalancer", software.amazon.awscdk.services.elasticloadbalancingv2.IApplicationLoadBalancer.class);
    }
}
